gatenlp.processing.normalizer API documentation
Description: Module that provides classes for normalizers. Normalizers are annotators which change the text of selected annotations or the entire text of the …

# Module `gatenlp.processing.normalizer`

Module that provides classes for normalizers. Normalizers are annotators which change the text of selected annotations or the entire text of the document. Since the text of a document is immutable, such Normalizers return a new document with the modified text. Since the text is modified any annotations present in the document may be invalid, therefore all annotations are removed when the new document is returned. Document features are preserved. Any changelog is preserved but the normalization is not logged.

Expand source code

    """
    Module that provides classes for normalizers. Normalizers are annotators which change the text of selected
     annotations or the entire text of the document.
    Since the text of a document is immutable, such Normalizers return a new document with the modified text.
    Since the text is modified any annotations present in the document may be invalid, therefore all annotations
    are removed when the new document is returned. Document features are preserved. Any changelog is preserved but
    the normalization is not logged.
    """

    from gatenlp.processing.annotator import Annotator

    class Normalizer(Annotator):
        """
        Base class of all normalizers.
        """

        pass

    class TextNormalizer(Normalizer):
        """
        NOT YET IMPLEMENTED
        """

        pass

## Classes

`class Normalizer`

  Base class of all normalizers.

  Expand source code

      class Normalizer(Annotator):
          """
          Base class of all normalizers.
          """

          pass

  ### Ancestors

  - Annotator
  - abc.ABC

  ### Subclasses

  - TextNormalizer

  ### Inherited members

  - `Annotator`:
    - `__call__`
    - `finish`
    - `pipe`
    - `reduce`
    - `start`
`class TextNormalizer`

  NOT YET IMPLEMENTED

  Expand source code

      class TextNormalizer(Normalizer):
          """
          NOT YET IMPLEMENTED
          """

          pass

  ### Ancestors

  - Normalizer
  - Annotator
  - abc.ABC

  ### Inherited members

  - `Normalizer`:
    - `__call__`
    - `finish`
    - `pipe`
    - `reduce`
    - `start`